
## Open IoE


Open IoE is a simple IoT platform to operate IoT devices.

There are two options available,

1. Python Library (Client) 
2. Web services (REST APIs)
---

### 1\. Python Library

Users are expected to take these steps,
1. Install Python Library

    `pip install openioe`

2. Write the client code using the following methods

#### Method List:
<table><tbody><tr><td><strong>No</strong></td><td><strong>Method</strong></td><td><strong>Description</strong></td><td><strong>Example</strong></td></tr><tr><td>1</td><td>ReadValue</td><td>To read the sensor data from single nodes. Type of data is "Numeric/String"</td><td><pre><code  class="language-python">from  openioe.openioe_apis  import *
oi=openioe_apis()
oi.APIKey='xxxxxxxxxxxxxxxxxxxx';
oi.DeviceID=xx
oi.DevicePin=xxx
SensorData,ResposeCode=oi.ReadValue()
print(SensorData)
print(ResposeCode)</code></pre></td></tr>
<tr><td>2</td><td>WriteValue</td><td>To modify the control signal at single nodes. Type of data is "Numeric/String".</td><td><pre><code  class="language-python">from  openioe.openioe_apis  import *
oi=openioe_apis()
oi.APIKey='xxxxxxxxxxxxxxxxxxxx';
oi.DeviceID=xx
oi.DevicePin=xx
oi.Data=10
SensorData,ResposeCode=oi.WriteValue()
print(SensorData)
print(ResposeCode)</code></pre></td></tr>
<tr><td>3</td><td>ReadJSON</td><td>To read the sensor data from single nodes. Type of data is "JSON".</td><td><pre><code  class="language-python">from  openioe.openioe_apis  import *
oi=openioe_apis()
oi.APIKey='xxxxxxxxxxxxxxxxxxxx';
oi.DeviceID=xx
oi.DevicePin=xxx
SensorData,ResposeCode=oi.ReadJSON()
print(SensorData)
print(ResposeCode)</code></pre></td></tr>
<tr><td>4</td><td>WriteJSON</td><td>To modify the control signal at single nodes. Type of data is "JSON".</td><td><pre><code  class="language-python">from  openioe.openioe_apis  import *
oi=openioe_apis()
oi.APIKey='xxxxxxxxxxxxxxxxxxxx';
oi.DeviceID=xx
oi.DevicePin=xxx
oi.DataJSON={'Value': '10'}
SensorData,ResposeCode=oi.WriteJSON()
print(SensorData)
print(ResposeCode)</code></pre></td></tr>
<tr><td>5</td><td>ReadXML</td><td>To read the sensor data from single nodes. Type of data is "XML".</td><td><pre><code  class="language-python">from  openioe.openioe_apis  import *
oi=openioe_apis()
oi.APIKey='xxxxxxxxxxxxxxxxxxxx';
oi.DeviceID=xx
oi.DevicePin=xxx
SensorData,ResposeCode=oi.ReadXML()
print(SensorData)
print(ResposeCode)</code></pre></td></tr>
<tr><td>6</td><td>WriteXML</td><td>To modify the control signal at single nodes. Type of data is "XML".</td><td><pre><code  class="language-python">from  openioe.openioe_apis  import *
oi=openioe_apis()
oi.APIKey='xxxxxxxxxxxxxxxxxxxx';
oi.DeviceID=xx
oi.DevicePin=xxx
oi.DataXML='<Name>OpenIoE</Name>'
SensorData,ResposeCode=oi.WriteXML()
print(SensorData)
print(ResposeCode)</code></pre></td></tr>
<tr><td>7</td><td>Read</td><td>To read the sensor data from multiple nodes. Type of data is "Numeric/String".</td><td><pre><code  class="language-python">from  openioe.openioe_apis  import *
oi=openioe_apis()
oi.APIKey='xxxxxxxxxxxxxxxxxxxx';
oi.UserIDPinAPIKeys=[[xx, xxx], [x, xxx]]
SensorData,ResposeCode=oi.Read()
print(SensorData)
print(ResposeCode)</code></pre></td></tr>
<tr><td>8</td><td>Write</td><td>To modify the control signal at multiple nodes. Type of data is "Numeric/String".</td><td><pre><code  class="language-python">from openioe.openioe_apis import *
oi=openioe_apis()
oi.APIKey='xxxxxxxxxxxxxxxxxxxx';
oi.UserIDPinAPIKeys=[[xx, xxx], [xx, xxx]]
oi.Data=[xx,xx]
Confirmation,ResposeCode=oi.ReadAPI()
print(Confirmation)
print(ResposeCode)</code></pre></td></tr><tr><td>3</td><td>Developer</td><td>To display the developer information</td><td><pre><code  class="language-python">from openioe.openioe_apis import *
oi=openioe_apis()
oi.Developer()</code></pre></td></tr></tbody></table>

  

---

### 2\. Web Services

Users are expected to take these steps,

1. Register and login to OpenIoE- [Register/Login](https://openioe.gnanodaya.org/)

2. Create API Key/ Get API Key from OpenIoE.

3. Embed the API Key, Device ID and Pin into the client code.

 
#### Visit the OpenIoE 3.0 web portal at [https://openioe.gnanodaya.org](https://openioe.gnanodaya.org)

#### Visit the OpenIoE 3.0 Help Portal at [https://openioedoc.gnanodaya.org](https://openioedoc.gnanodaya.org)
  

#### API List:

<table><tbody><tr><td><strong>No</strong></td><td><strong>API</strong></td><td><strong>Description</strong></td><td><strong>Type</strong></td><td><strong>Example</strong></td></tr><tr><td>1</td><td>showdevicevalue</td><td>To get hardware value from web service.</td><td>http get</td><td><pre><code  class="language-plaintext">&lt;endpoint&gt;/showdevicevalue/&lt;apikey&gt;/2/433</code></pre></td></tr><tr><td>2</td><td>updatedevicevalue</td><td>Update the hardware value passed as a parameter</td><td>http get</td><td><pre><code  class="language-plaintext">&lt;endpoint&gt;/updatedevievalue/&lt;apikey&gt;/2/433/2</code></pre></td></tr><tr><td>3</td><td>showdevicejson</td><td>To get hardware JSON from web service.</td><td>http get</td><td><pre><code  class="language-plaintext">&lt;endpoint&gt;/showdevicejson/&lt;apikey&gt;/2/433</code></pre></td></tr><tr><td>4</td><td>updatedevicejson</td><td>Update the hardware JSON passed as parameter</td><td>http post</td><td><pre><code  class="language-plaintext">&lt;endpoint&gt;/updatedevicejson/&lt;apikey&gt;/2/433 &lt;Data&gt;</code></pre></td></tr><tr><td>5</td><td>showdevicexml</td><td>To get hardware XML file from web service.</td><td>http get</td><td><pre><code  class="language-plaintext">&lt;endpoint&gt;/showdevicexml/&lt;apikey&gt;/2/433</code></pre></td></tr><tr><td>6</td><td>updatedevicexml</td><td>Update the hardware XML passed as parameter</td><td>http post</td><td><pre><code  class="language-plaintext">&lt;endpoint&gt;/updatedevicexml/&lt;apikey&gt;/2/433 &lt;Data&gt;</code></pre></td></tr></tbody></table>

  

---

 
### Developers

<p>
<img  src="https://venkataswamy.in/images/img1.jpg"  alt="Dr. Venkataswamy R"  width="100"/>
</p>
<div><div  dir="ltr"><div  style="font-size:small"><i><font  face="times new roman, serif">Thanks and Regards</font><font  face="arial">,</font></i></div><div  style="font-family:arial"><b><font  size="2"  color="#0000ff"><span></span>Venkataswamy R</font><font  size="2"><span></span></font></b></div><div  style="font-size:small"><span  style="color:rgb(0,0,0)"><font  face="trebuchet ms, sans-serif"><b>Assistant Professor,</b></font></span></div><div  style="font-size:small"><span  style="color:rgb(0,0,0)"><font  face="trebuchet ms, sans-serif"><b>Department of Electrical and Electronics Engineering,</b></font></span></div><div  style="font-size:small"><span  style="color:rgb(0,0,0)"><font  face="trebuchet ms, sans-serif"><b>School of Engineering and Technology,<br></b></font></span></div><div  style="font-size:small"><span  style="color:rgb(0,0,0)"><font  face="trebuchet ms, sans-serif"><b>Christ (Deemed to be University),</b></font></span></div><div  style="font-size:small"><span  style="color:rgb(56,118,29)"><font  face="trebuchet ms, sans-serif"><b><span  style="color:rgb(0,0,0)">Bengaluru-560074, India</span><br><br></b></font></span></div><div  style="font-family:arial;font-size:small"><b  style="color:rgb(7,55,99);font-family:'trebuchet ms',sans-serif"><i><img  src="https://ci4.googleusercontent.com/proxy/JGrPNyQPabY_rra4ygFQhpV3cMA7ITqb5WxBKVcm5J7nUXsWZgk4oUuqR-1Dso97mGx5TF4OvAWyEvAm6fA0h9EhgVZcO6VnO77JetkXhoxX6-7YrakgsA=s0-d-e1-ft#https://openclipart.org/image/2400px/svg_to_png/262221/phone25.png"  alt="Image result for phone icon"  style="margin-top:0px"  width="17"  height="14"> 080-4012-9961 (O)</i></b><font  face="trebuchet ms, sans-serif"  color="#073763"><b><i>&nbsp;&nbsp;  </i></b></font><b  style="color:rgb(7,55,99);font-family:'trebuchet ms',sans-serif"><i><img  src="https://ci4.googleusercontent.com/proxy/xDyzoCUBYbAyKgjwt27Jl4lkN_6MrkWuk-4BQ2IgMCZEuCMwJLtZjRYqLSrgS6SGWQcpQOVuNmBzqrKJpes9riut82x8hJ1GJVKL=s0-d-e1-ft#http://simpleicon.com/wp-content/uploads/mobile-1.png"  style="margin-top:0px"  alt="Image result for mobile icon"  width="21"  height="21">+91-7829222446</i></b><i><b>&nbsp;  </b></i><img  src="https://lh4.googleusercontent.com/-FqpLVHU8eMw/AAAAAAAAAAI/AAAAAAAAABM/ivbX55TtoV4/photo.jpg"  alt="Related image"  style="margin-top:0px"  width="21"  height="21"><span><b  style="color:rgb(7,55,99);font-family:'trebuchet ms',sans-serif"><i>  <a  href="http://venkataswamy.in"  target="_blank">venkatswamy.in</a><br><br><br></i></b></span></div></div></div>
